==> lifestyle-sylius-rest-client-bundle-2.0.0-30880b.zip: src/Services/ProductVariant/Version1/Update/Mapper.php <==
<?php

/**
 * Class Mapper
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update;

use Lifestyle\DataCollector\DataCollectorInterface;
use Lifestyle\Sylius\RestApiClientBundle\Exception\InvalidConfigurationException;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Response\ProductOption as ProductOptionResponse;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\ChannelPrice;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\ProductVariantInterface;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\Translation;

/**
 * Class Mapper
 * @package Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update
 */
class Mapper
{
    /**
     * @var string
     */
    private $modelClass;

    /**
     * @param string $modelClass
     */
    public function setModelClass(string $modelClass)
    {
        $this->modelClass = $modelClass;
    }

    /**
     * @param DataCollectorInterface $collector
     * @return ProductVariantInterface
     * @throws InvalidConfigurationException
     */
    public function mapRequestModel(DataCollectorInterface $collector)
    {
        $product = $this->createModel();
        $product
            ->setCode($collector->getItemValue('id'))
            ->setOnHand($collector->getItemValue('onHand'))
            ->setTracked($collector->getItemValue('tracked'))
            //->setTaxCategory($collector->getItemValue('taxCategory'))
            ->setHeight($collector->getItemValue('height'))
            ->setWidth($collector->getItemValue('width'))
            ->setDepth($collector->getItemValue('depth'))
            ->setWeight($collector->getItemValue('weight'))
            ->setVersion($collector->getItemValue('version'));

        if ($collector->hasItem('channelPrices')) {
            foreach ($collector->getItemValue('channelPrices') as $channelCode => $channelPrice) {
                $channelPriceItem = new ChannelPrice();
                $channelPriceItem->setChannel($channelCode);
                $channelPriceItem->setPrice($channelPrice['price']);
                $channelPriceItem->setOriginalPrice($channelPrice['originalPrice']);
                $product->addChannelPricing($channelPriceItem);
            }
        }

        $locales = $collector->getCollectedLocales();
        foreach ($locales as $locale) {
            $productName = (string)($collector->getItemValue('name', $locale) ?: $collector->getItemValue('id'));
            $translation = new Translation();
            $translation->setLocale($locale);
            $translation->setName($productName);
            $product->addTranslation($translation);
        }

        // create product options if not exist
        if ($collector->hasItem('options')) {
            $options = $collector->getItemValue('options');
            foreach ((is_array($options) ? $options : [$options]) as $optionCode) {
                $optionValues = [];
                if ($collector->hasItem('options_' . $optionCode)) {
                    $optionValues = $collector->getItemValue('options_' . $optionCode);
                }
                foreach ((is_array($optionValues) ? $optionValues : [$optionValues]) as $optionValue) {
                    $product->addOptionValue($optionCode, ProductOptionResponse::buildCode($optionCode, $optionValue));
                }
            }
        }

        return $product;
    }

    /**
     * @return ProductVariantInterface
     * @throws InvalidConfigurationException
     */
    private function createModel(): ProductVariantInterface
    {
        $model = new $this->modelClass;

        if (!$model instanceof ProductVariantInterface) {
            throw new InvalidConfigurationException(
                sprintf(
                    'Request model class for updating product variants must implement %s. %s given.',
                    ProductVariantInterface::class,
                    $this->modelClass
                )
            );
        }

        return $model;
    }
}

==> lifestyle-sylius-rest-client-bundle-2.1.0-420872.zip: src/Services/ProductVariant/Version1/Update/Mapper.php <==
<?php

/**
 * Class Mapper
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update;

use Lifestyle\DataCollector\DataCollectorInterface;
use Lifestyle\Sylius\RestApiClientBundle\Exception\InvalidConfigurationException;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Response\ProductOption as ProductOptionResponse;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\ChannelPrice;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\ProductVariantInterface;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\Translation;

/**
 * Class Mapper
 * @package Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update
 */
class Mapper
{
    /**
     * @var string
     */
    private $modelClass;

    /**
     * @param string $modelClass
     */
    public function setModelClass(string $modelClass)
    {
        $this->modelClass = $modelClass;
    }

    /**
     * @param DataCollectorInterface $collector
     * @return ProductVariantInterface
     * @throws InvalidConfigurationException
     */
    public function mapRequestModel(DataCollectorInterface $collector)
    {
        $product = $this->createModel();
        $product->setCode($collector->getItemValue('id'));
        $product->setOnHand($collector->getItemValue('onHand'));
        $product->setTracked($collector->getItemValue('tracked'));
        $product->setTaxCategory($collector->getItemValue('taxCategory'));
        $product->setHeight($collector->getItemValue('height'));
        $product->setWidth($collector->getItemValue('width'));
        $product->setDepth($collector->getItemValue('depth'));
        $product->setWeight($collector->getItemValue('weight'));
        $product->setVersion($collector->getItemValue('version'));

        if ($collector->hasItem('enabled')) {
            $product->setEnabled((bool)$collector->getItemValue('enabled'));
        }

        if ($collector->hasItem('channelPrices')) {
            foreach ($collector->getItemValue('channelPrices') as $channelCode => $channelPrice) {
                $channelPriceItem = new ChannelPrice();
                $channelPriceItem->setChannel($channelCode);
                $channelPriceItem->setPrice($channelPrice['price']);
                $channelPriceItem->setOriginalPrice($channelPrice['originalPrice']);
                $product->addChannelPricing($channelPriceItem);
            }
        }

        $locales = $collector->getCollectedLocales();
        foreach ($locales as $locale) {
            $productName = (string)($collector->getItemValue('name', $locale) ?: $collector->getItemValue('id'));
            $translation = new Translation();
            $translation->setLocale($locale);
            $translation->setName($productName);
            $product->addTranslation($translation);
        }

        // create product options if not exist
        if ($collector->hasItem('options')) {
            $options = $collector->getItemValue('options');
            foreach ((is_array($options) ? $options : [$options]) as $optionCode) {
                $optionValues = [];
                if ($collector->hasItem('options_' . $optionCode)) {
                    $optionValues = $collector->getItemValue('options_' . $optionCode);
                }
                foreach ((is_array($optionValues) ? $optionValues : [$optionValues]) as $optionValue) {
                    $product->addOptionValue($optionCode, ProductOptionResponse::buildCode($optionCode, $optionValue));
                }
            }
        }

        return $product;
    }

    /**
     * @return ProductVariantInterface
     * @throws InvalidConfigurationException
     */
    private function createModel(): ProductVariantInterface
    {
        $model = new $this->modelClass;

        if (!$model instanceof ProductVariantInterface) {
            throw new InvalidConfigurationException(
                sprintf(
                    'Request model class for updating product variants must implement %s. %s given.',
                    ProductVariantInterface::class,
                    $this->modelClass
                )
            );
        }

        return $model;
    }
}
